CPCCARotator
============

.. currentmodule:: xeofs.cross

.. autoclass:: CPCCARotator
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~CPCCARotator.__init__
      ~CPCCARotator.components
      ~CPCCARotator.compute
      ~CPCCARotator.correlation_coefficients_X
      ~CPCCARotator.correlation_coefficients_Y
      ~CPCCARotator.cross_correlation_coefficients
      ~CPCCARotator.deserialize
      ~CPCCARotator.fit
      ~CPCCARotator.fraction_variance_X_explained_by_X
      ~CPCCARotator.fraction_variance_Y_explained_by_X
      ~CPCCARotator.fraction_variance_Y_explained_by_Y
      ~CPCCARotator.get_params
      ~CPCCARotator.get_serialization_attrs
      ~CPCCARotator.heterogeneous_patterns
      ~CPCCARotator.homogeneous_patterns
      ~CPCCARotator.inverse_transform
      ~CPCCARotator.load
      ~CPCCARotator.predict
      ~CPCCARotator.save
      ~CPCCARotator.scores
      ~CPCCARotator.serialize
      ~CPCCARotator.squared_covariance_fraction
      ~CPCCARotator.transform
   
   

   
   
   